# Attempt to translate Debbie's cropping systems SAS code into R and see if it gets the same results
# QDR / 28 Oct 2021

library(tidyverse)
library(lme4)
library(lmerTest)

# Read and clean data
dat0610 <- read_delim('20062010dat.txt', delim = '\t') %>%
  mutate(logCFU = log(CFU),
         ccrop = if_else(ccrop == 'austinwinterpea', 'Austrianwinterpea', ccrop)) %>%
  arrange(yr, ccrop, pcrop)

# Take a look
theme_set(theme_bw() + theme(strip.background = element_blank()))

# Distribution of CFU
# It is right skewed so not acceptable to use a normal
ggplot(dat0610, aes(x = CFU)) +
  geom_histogram(aes(y = ..density..)) +
  geom_density(color = 'slateblue', size = 1) +
  stat_function(fun = dnorm, args = list(mean = mean(dat0610$CFU, na.rm = TRUE), sd = sd(dat0610$CFU, na.rm = TRUE)), color = 'indianred', size = 1)

# Look at log transformation
# Looks much better
ggplot(dat0610, aes(x = logCFU)) +
  geom_histogram(aes(y = ..density..)) +
  geom_density(color = 'slateblue', size = 1) +
  stat_function(fun = dnorm, args = list(mean = mean(dat0610$logCFU, na.rm = TRUE), sd = sd(dat0610$logCFU, na.rm = TRUE)), color = 'indianred', size = 1)

# Now look at differences in treatments (use log scale)
# Interactions
ggplot(dat0610, aes(x = ccrop, y = CFU, fill = pcrop, group = interaction(ccrop, pcrop))) +
  facet_wrap(~ yr) +
  geom_boxplot() +
  scale_y_log10()

# Main effects
ggplot(dat0610, aes(x = ccrop, y = CFU)) +
  facet_wrap(~ yr) +
  geom_boxplot() +
  scale_y_log10()

ggplot(dat0610, aes(x = pcrop, y = CFU)) +
  facet_wrap(~ yr) +
  geom_boxplot() +
  scale_y_log10()

# Replicate final model "anova2" from Debbie's SAS code
# Where year is a random effect
# This is her model spec:
# model lcfu= pcrop ccrop pcrop*ccrop/ddfm=kr;
# random yr yr*pcrop cblk(pcrop yr) rep(cblk pcrop yr) yr*ccrop(pcrop) cblk*ccrop(pcrop yr);
# I don't see why she put rep in as a random effect, nor all the interaction effects with year and block.
# Just use random intercepts for year and block.

yr_random_fit <- lmer(logCFU ~ pcrop * ccrop + (1|yr) + (1|cblk), data = dat0610, REML = TRUE)

# Appears to confirm that the only significant effect is the main effect of wheat ccrop (<0)
summary(yr_random_fit)
confint(yr_random_fit, level = 0.95, method = 'boot', nsim = 999, type = 'parametric')

# Look at main effects only without interaction
# Here we also see a potential effect of fallow.
yr_random_onlymain_fit <- lmer(logCFU ~ pcrop + ccrop + (1|yr) + (1|cblk), data = dat0610, REML = TRUE)

summary(yr_random_onlymain_fit)
confint(yr_random_onlymain_fit, level = 0.95, method = 'boot', nsim = 999, type = 'parametric')

lsmeansLT(yr_random_fit, which = 'pcropcorn', ddf = 'Kenward-Roger') # Returns no output.
